==> events-0.9.1-sources.jar: software/amazon/awscdk/services/events/EventRuleRefProps.java <==
package software.amazon.awscdk.services.events;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:17:14.800Z")
public interface EventRuleRefProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    software.amazon.awscdk.services.events.RuleArn getEventRuleArn();
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    void setEventRuleArn(final software.amazon.awscdk.services.events.RuleArn value);

    /**
     * @return a {@link Builder} of {@link EventRuleRefProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EventRuleRefProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.events.RuleArn _eventRuleArn;

        /**
         * Sets the value of EventRuleArn
         * @param value The value of the event rule Amazon Resource Name (ARN), such as
arn:aws:events:us-east-2:123456789012:rule/example.
         * @return {@code this}
         */
        public Builder withEventRuleArn(final software.amazon.awscdk.services.events.RuleArn value) {
            this._eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EventRuleRefProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EventRuleRefProps build() {
            return new EventRuleRefProps() {
                private software.amazon.awscdk.services.events.RuleArn $eventRuleArn = java.util.Objects.requireNonNull(_eventRuleArn, "eventRuleArn is required");

                @Override
                public software.amazon.awscdk.services.events.RuleArn getEventRuleArn() {
                    return this.$eventRuleArn;
                }

                @Override
                public void setEventRuleArn(final software.amazon.awscdk.services.events.RuleArn value) {
                    this.$eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.EventRuleRefProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public software.amazon.awscdk.services.events.RuleArn getEventRuleArn() {
            return this.jsiiGet("eventRuleArn", software.amazon.awscdk.services.events.RuleArn.class);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public void setEventRuleArn(final software.amazon.awscdk.services.events.RuleArn value) {
            this.jsiiSet("eventRuleArn", java.util.Objects.requireNonNull(value, "eventRuleArn is required"));
        }
    }
}

==> events-0.9.2-sources.jar: software/amazon/awscdk/services/events/EventRuleRefProps.java <==
package software.amazon.awscdk.services.events;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-20T13:04:04.143Z")
public interface EventRuleRefProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    java.lang.String getEventRuleArn();
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    void setEventRuleArn(final java.lang.String value);

    /**
     * @return a {@link Builder} of {@link EventRuleRefProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EventRuleRefProps}
     */
    final class Builder {
        private java.lang.String _eventRuleArn;

        /**
         * Sets the value of EventRuleArn
         * @param value The value of the event rule Amazon Resource Name (ARN), such as
arn:aws:events:us-east-2:123456789012:rule/example.
         * @return {@code this}
         */
        public Builder withEventRuleArn(final java.lang.String value) {
            this._eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EventRuleRefProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EventRuleRefProps build() {
            return new EventRuleRefProps() {
                private java.lang.String $eventRuleArn = java.util.Objects.requireNonNull(_eventRuleArn, "eventRuleArn is required");

                @Override
                public java.lang.String getEventRuleArn() {
                    return this.$eventRuleArn;
                }

                @Override
                public void setEventRuleArn(final java.lang.String value) {
                    this.$eventRuleArn = java.util.Objects.requireNonNull(value, "eventRuleArn is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.EventRuleRefProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public java.lang.String getEventRuleArn() {
            return this.jsiiGet("eventRuleArn", java.lang.String.class);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public void setEventRuleArn(final java.lang.String value) {
            this.jsiiSet("eventRuleArn", java.util.Objects.requireNonNull(value, "eventRuleArn is required"));
        }
    }
}
